@@ -595,6 +595,7 @@ def plot_model(
     label: bool = False,
     scale: float = 1,
     save: bool = False,
+    display_format: Optional[str] = None
 ):
 
     """
@@ -647,12 +648,17 @@ def plot_model(
         When set to True, plot is saved in the current working directory.
 
 
+    display_format: str, default = None
+        To display plots in Streamlit (https://www.streamlit.io/), set this to 'streamlit'.
+        Currently, not all plots are supported.
+
+
     Returns:
         None
 
     """
     return pycaret.internal.tabular.plot_model(
-        model, plot=plot, feature_name=feature, label=label, scale=scale, save=save
+        model, plot=plot, feature_name=feature, label=label, scale=scale, save=save, display_format=display_format
     )
 
 
