@@ -63,6 +63,9 @@ class ClassifierContainer(ModelContainer):
         If None, will try to automatically determine.
     is_soft_voting_supported : bool, default = None
         If None, will try to automatically determine.
+    tunable : type, default = None
+        If a special tunable model is used for tuning, type of
+        that model, else None.
 
     Attributes
     ----------
@@ -95,7 +98,9 @@ class ClassifierContainer(ModelContainer):
         If None, will try to automatically determine.
     is_soft_voting_supported : bool
         If None, will try to automatically determine.
-
+    tunable : type
+        If a special tunable model is used for tuning, type of
+        that model, else None.
     """
 
     def __init__(
@@ -114,6 +119,7 @@ class ClassifierContainer(ModelContainer):
         is_gpu_enabled: Optional[bool] = None,
         is_boosting_supported: Optional[bool] = None,
         is_soft_voting_supported: Optional[bool] = None,
+        tunable: Optional[type] = None,
     ) -> None:
 
         self.shap = shap
@@ -144,6 +150,7 @@ class ClassifierContainer(ModelContainer):
         self.tune_grid = param_grid_to_lists(tune_grid)
         self.tune_distribution = tune_distribution
         self.tune_args = tune_args
+        self.tunable = tunable
 
         try:
             model_instance = class_def()
@@ -208,6 +215,7 @@ class ClassifierContainer(ModelContainer):
                 ("GPU Enabled", self.is_gpu_enabled),
                 ("Boosting Supported", self.is_boosting_supported),
                 ("Soft Voting", self.is_soft_voting_supported),
+                ("Tunable Class", self.tunable),
             ]
 
         return dict(d)
@@ -241,17 +249,16 @@ class LogisticRegressionClassifierContainer(ClassifierContainer):
         tune_distributions = {}
 
         # common
-        tune_grid["penalty"] = ["l2", "none"]
-        tune_grid["C"] = np_list_arange(0, 10, 0.001, inclusive=True)
+        tune_grid["C"] = np_list_arange(0.001, 10, 0.001, inclusive=True)
 
         if gpu_imported:
-            tune_grid["penalty"] += ["l1"]
+            tune_grid["penalty"] = ["l2", "l1"]
         else:
             args["random_state"] = globals_dict["seed"]
 
             tune_grid["class_weight"] = ["balanced", {}]
 
-        tune_distributions["C"] = UniformDistribution(0, 10)
+        tune_distributions["C"] = UniformDistribution(0.001, 10)
         leftover_parameters_to_categorical_distributions(tune_grid, tune_distributions)
 
         super().__init__(
@@ -605,7 +612,8 @@ class MLPClassifierContainer(ClassifierContainer):
     def __init__(self, globals_dict: dict) -> None:
         logger = get_logger()
         np.random.seed(globals_dict["seed"])
-        from pycaret.internal.tunable import TunableMLPClassifier as MLPClassifier
+        from sklearn.neural_network import MLPClassifier
+        from pycaret.internal.tunable import TunableMLPClassifier
 
         args = {"random_state": globals_dict["seed"], "max_iter": 500}
         tune_args = {}
@@ -653,6 +661,7 @@ class MLPClassifierContainer(ClassifierContainer):
             tune_args=tune_args,
             shap=False,
             is_turbo=False,
+            tunable=TunableMLPClassifier,
         )
 
 
@@ -841,7 +850,22 @@ class AdaBoostClassifierContainer(ClassifierContainer):
         tune_args = {}
         tune_grid = {
             "n_estimators": np_list_arange(10, 300, 10, inclusive=True),
-            "learning_rate": np_list_arange(0.001, 0.5, 0.001, inclusive=True),
+            "learning_rate": [
+                0.0000001,
+                0.000001,
+                0.0001,
+                0.001,
+                0.01,
+                0.0005,
+                0.005,
+                0.05,
+                0.1,
+                0.15,
+                0.2,
+                0.3,
+                0.4,
+                0.5,
+            ],
             "algorithm": ["SAMME", "SAMME.R"],
         }
         tune_distributions = {
@@ -873,7 +897,22 @@ class GradientBoostingClassifierContainer(ClassifierContainer):
         tune_args = {}
         tune_grid = {
             "n_estimators": np_list_arange(10, 300, 10, inclusive=True),
-            "learning_rate": np_list_arange(0.001, 0.5, 0.001, inclusive=True),
+            "learning_rate": [
+                0.0000001,
+                0.000001,
+                0.0001,
+                0.001,
+                0.01,
+                0.0005,
+                0.005,
+                0.05,
+                0.1,
+                0.15,
+                0.2,
+                0.3,
+                0.4,
+                0.5,
+            ],
             "subsample": np_list_arange(0.2, 1, 0.05, inclusive=True),
             "min_samples_split": [2, 4, 5, 7, 9, 10],
             "min_samples_leaf": [1, 2, 3, 4, 5],
@@ -1036,6 +1075,21 @@ class XGBClassifierContainer(ClassifierContainer):
     def __init__(self, globals_dict: dict) -> None:
         logger = get_logger()
         np.random.seed(globals_dict["seed"])
+        try:
+            import xgboost
+        except ImportError:
+            logger.warning("Couldn't import xgboost.XGBClassifier")
+            self.active = False
+            return
+
+        xgboost_version = tuple([int(x) for x in xgboost.__version__.split(".")])
+        if xgboost_version < (1, 1, 0):
+            logger.warning(
+                f"Wrong xgboost version. Expected xgboost>=1.1.0, got xgboost=={xgboost_version}"
+            )
+            self.active = False
+            return
+
         from xgboost import XGBClassifier
 
         args = {
@@ -1047,7 +1101,22 @@ class XGBClassifierContainer(ClassifierContainer):
         }
         tune_args = {}
         tune_grid = {
-            "learning_rate": np_list_arange(0.001, 0.5, 0.001, inclusive=True),
+            "learning_rate": [
+                0.0000001,
+                0.000001,
+                0.0001,
+                0.001,
+                0.01,
+                0.0005,
+                0.005,
+                0.05,
+                0.1,
+                0.15,
+                0.2,
+                0.3,
+                0.4,
+                0.5,
+            ],
             "n_estimators": np_list_arange(10, 300, 10, inclusive=True),
             "subsample": [0.2, 0.3, 0.5, 0.7, 0.9, 1],
             "max_depth": np_list_arange(1, 11, 1, inclusive=True),
@@ -1141,8 +1210,41 @@ class LGBMClassifierContainer(ClassifierContainer):
         }
         tune_args = {}
         tune_grid = {
-            "num_leaves": [10, 20, 30, 40, 50, 60, 70, 80, 90, 100, 150, 200],
-            "learning_rate": np_list_arange(0.001, 0.5, 0.001, inclusive=True),
+            "num_leaves": [
+                2,
+                4,
+                6,
+                8,
+                10,
+                20,
+                30,
+                40,
+                50,
+                60,
+                70,
+                80,
+                90,
+                100,
+                150,
+                200,
+                256,
+            ],
+            "learning_rate": [
+                0.0000001,
+                0.000001,
+                0.0001,
+                0.001,
+                0.01,
+                0.0005,
+                0.005,
+                0.05,
+                0.1,
+                0.15,
+                0.2,
+                0.3,
+                0.4,
+                0.5,
+            ],
             "n_estimators": np_list_arange(10, 300, 10, inclusive=True),
             "min_split_gain": [0, 0.1, 0.2, 0.3, 0.4, 0.5, 0.6, 0.7, 0.8, 0.9],
             "reg_alpha": [
@@ -1193,21 +1295,20 @@ class LGBMClassifierContainer(ClassifierContainer):
             ],
             "feature_fraction": np_list_arange(0.4, 1, 0.1, inclusive=True),
             "bagging_fraction": np_list_arange(0.4, 1, 0.1, inclusive=True),
-            "bagging_freq": [1, 2, 3, 4, 5, 6, 7],
-            "min_child_samples": np_list_arange(5, 100, 5, inclusive=True),
+            "bagging_freq": [0, 1, 2, 3, 4, 5, 6, 7],
+            "min_child_samples": np_list_arange(1, 100, 5, inclusive=True),
         }
         tune_distributions = {
-            "num_leaves": IntUniformDistribution(10, 200),
+            "num_leaves": IntUniformDistribution(2, 256),
             "learning_rate": UniformDistribution(0.000001, 0.5, log=True),
             "n_estimators": IntUniformDistribution(10, 300),
             "min_split_gain": UniformDistribution(0, 1),
             "reg_alpha": UniformDistribution(0.0000000001, 10, log=True),
             "reg_lambda": UniformDistribution(0.0000000001, 10, log=True),
-            "min_data_in_leaf": IntUniformDistribution(10, 10000),
             "feature_fraction": UniformDistribution(0.4, 1),
             "bagging_fraction": UniformDistribution(0.4, 1),
-            "bagging_freq": IntUniformDistribution(1, 7),
-            "min_child_samples": IntUniformDistribution(5, 100),
+            "bagging_freq": IntUniformDistribution(0, 7),
+            "min_child_samples": IntUniformDistribution(1, 100),
         }
 
         leftover_parameters_to_categorical_distributions(tune_grid, tune_distributions)
@@ -1246,6 +1347,21 @@ class CatBoostClassifierContainer(ClassifierContainer):
     def __init__(self, globals_dict: dict) -> None:
         logger = get_logger()
         np.random.seed(globals_dict["seed"])
+        try:
+            import catboost
+        except ImportError:
+            logger.warning("Couldn't import catboost.CatBoostClassifier")
+            self.active = False
+            return
+
+        catboost_version = tuple([int(x) for x in catboost.__version__.split(".")])
+        if catboost_version < (0, 23, 2):
+            logger.warning(
+                f"Wrong catboost version. Expected catboost>=0.23.2, got catboost=={catboost_version}"
+            )
+            self.active = False
+            return
+
         from catboost import CatBoostClassifier
 
         # suppress output
@@ -1264,12 +1380,29 @@ class CatBoostClassifierContainer(ClassifierContainer):
         }
         tune_args = {}
         tune_grid = {
+            "eta": [
+                0.0000001,
+                0.000001,
+                0.0001,
+                0.001,
+                0.01,
+                0.0005,
+                0.005,
+                0.05,
+                0.1,
+                0.15,
+                0.2,
+                0.3,
+                0.4,
+                0.5,
+            ],
             "depth": list(range(1, 12)),
             "n_estimators": np_list_arange(10, 300, 10, inclusive=True),
             "random_strength": np_list_arange(0, 0.8, 0.1, inclusive=True),
             "l2_leaf_reg": [1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 20, 30, 50, 100, 200],
         }
         tune_distributions = {
+            "eta": UniformDistribution(0.000001, 0.5, log=True),
             "depth": IntUniformDistribution(1, 11),
             "n_estimators": IntUniformDistribution(10, 300),
             "random_strength": UniformDistribution(0, 0.8),
@@ -1364,7 +1497,8 @@ class VotingClassifierContainer(ClassifierContainer):
     def __init__(self, globals_dict: dict) -> None:
         logger = get_logger()
         np.random.seed(globals_dict["seed"])
-        from pycaret.internal.tunable import TunableVotingClassifier as VotingClassifier
+        from sklearn.ensemble import VotingClassifier
+        from pycaret.internal.tunable import TunableVotingClassifier
 
         args = {}
         tune_args = {}
@@ -1387,6 +1521,7 @@ class VotingClassifierContainer(ClassifierContainer):
             shap=False,
             is_special=True,
             is_gpu_enabled=False,
+            tunable=TunableVotingClassifier,
         )
 
 
