@@ -563,6 +563,7 @@ def setup(
         "feature": "Feature Importance",
         "feature_all": "Feature Importance (All)",
         "tree": "Decision Tree",
+        "residuals_interactive": "Interactive Residuals",
     }
 
     if log_plots == True:
@@ -1007,6 +1008,7 @@ def tune_model(
             - 'grid' : grid search
             - 'bayesian' : ``pip install scikit-optimize``
             - 'hyperopt' : ``pip install hyperopt``
+            - 'optuna' : ``pip install optuna``
             - 'bohb' : ``pip install hpbandster ConfigSpace``
 
         - 'optuna' possible values:
@@ -1403,6 +1405,7 @@ def plot_model(
     groups: Optional[Union[str, Any]] = None,
     use_train_data: bool = False,
     verbose: bool = True,
+    display_format: Optional[str] = None
 ) -> str:
 
     """
@@ -1427,6 +1430,7 @@ def plot_model(
     plot: str, default = 'residual'
         List of available plots (ID - Name):
 
+        * 'residuals_interactive' - Interactive Residual plots
         * 'residuals' - Residuals Plot
         * 'error' - Prediction Error Plot
         * 'cooks' - Cooks Distance Plot
@@ -1475,6 +1479,11 @@ def plot_model(
         When set to False, progress bar is not displayed.
 
 
+    display_format: str, default = None
+        To display plots in Streamlit (https://www.streamlit.io/), set this to 'streamlit'.
+        Currently, not all plots are supported.
+
+
     Returns:
         None
 
@@ -1491,6 +1500,7 @@ def plot_model(
         verbose=verbose,
         use_train_data=use_train_data,
         system=True,
+        display_format=display_format
     )
 
 
@@ -1568,6 +1578,7 @@ def interpret_model(
     feature: Optional[str] = None,
     observation: Optional[int] = None,
     use_train_data: bool = False,
+    save: bool = False,
     **kwargs,
 ):
 
@@ -1611,6 +1622,10 @@ def interpret_model(
         of test data.
 
 
+    save: bool, default = False
+        When set to True, Plot is saved as a 'png' file in current working directory.
+
+
     **kwargs:
         Additional keyword arguments to pass to the plot.
 
@@ -1626,6 +1641,7 @@ def interpret_model(
         feature=feature,
         observation=observation,
         use_train_data=use_train_data,
+        save=save,
         **kwargs,
     )
 
